import _plotly_utils.basevalidators


class XtypeValidator(_plotly_utils.basevalidators.EnumeratedValidator):

    def __init__(self, plotly_name='xtype', parent_name='heatmap', **kwargs):
        super(XtypeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop('edit_type', 'calc+clearAxisTypes'),
            role=kwargs.pop('role', 'info'),
            values=kwargs.pop('values', ['array', 'scaled']),
            **kwargs
        )



import _plotly_utils.basevalidators


class LayoutValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(
        self, plotly_name='layout', parent_name='layout.template', **kwargs
    ):
        super(LayoutValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str=kwargs.pop('data_class_str', 'Layout'),
            data_docs=kwargs.pop('data_docs', """
"""),
            **kwargs
        )
